## Clicada

> Admin Command Line Interface to interact with cic-meta and cic-cache

### Pre-requisites

- Public key uploaded to `cic-auth-helper`
- PGP Keyring for your key

### Installation

Use either of the following installation methods:

1. Install from git release (recommended)

```bash
wget https://git.grassecon.net/grassrootseconomics/clicada/archive/v0.0.6.zip
unzip clicada-v0.0.6.zip
cd clicada
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements.txt --extra-index-url=https://pip.grassrootseconomics.net
```

2. Install from pip to path (non sudo)

```bash
pip3 install -UI --extra-index-url=https://pip.grassrootseconomics.net clicada
```

### GPG Keyring setup

PGP uses the default keyring, you can however pass in a custom keyring path.

To create a keyring from a specific key and get its path for `AUTH_KEYRING_PATH`:

```bash
# In some dir
gpg --homedir .gnupg --import private.pgp
pwd
```

### Usage

```bash
usage: clicada [...optional arguments] [...positional arguments]

positional arguments:
  {user,u,tag,t}
    user (u)            retrieve transactions for a user
    tag (t)             locally assign a display value to an identifier

optional arguments:
  -h, --help            show this help message and exit
  --no-logs             Turn off all logging
  -v                    Be verbose
  -vv                   Be very verbose
  -c CONFIG, --config CONFIG
                        Configuration directory
  -n NAMESPACE, --namespace NAMESPACE
                        Configuration namespace
  --dumpconfig {env,ini}
                        Output configuration and quit. Use with --raw to omit values and output schema only.
  --env-prefix ENV_PREFIX
                        environment prefix for variables to overwrite configuration
  -p P, --rpc-provider P
                        RPC HTTP(S) provider url
  --rpc-dialect RPC_DIALECT
                        RPC HTTP(S) backend dialect
  --height HEIGHT       Block height to execute against
  -i I, --chain-spec I  Chain specification string
  -u, --unsafe          Do not verify address checksums
  --seq                 Use sequential rpc ids
  -y Y, --key-file Y    Keystore file to use for signing or address
  --raw                 Do not decode output
  --fee-price FEE_PRICE
                        override fee price
  --fee-limit FEE_LIMIT
                        override fee limit

```

### Example

```bash
AUTH_PASSPHRASE=queenmarlena AUTH_KEYRING_PATH=/home/kamikaze/grassroots/usumbufu/tests/testdata/pgp/.gnupg/ AUTH_KEY=CCE2E1D2D0E36ADE0405E2D0995BB21816313BD5 CHAIN_SPEC=evm:byzantium:8996:bloxberg CIC_REGISTRY_ADDRESS=0xcf60ebc445b636a5ab787f9e8bc465a2a3ef8299 RPC_PROVIDER=https://rpc.grassecon.net TX_CACHE_URL=https://cache.grassecon.net HTTP_CORS_ORIGIN=https://auth.grassecon.net META_HTTP_ORIGIN=https://auth.grassecon.net:443 PYTHONPATH=. python clicada/runnable/view.py u --meta-url https://auth.grassecon.net +254711000000
```
